@@ -3,6 +3,8 @@ from django.contrib import admin
 from .models    import (User, Project, UserProjectEvent, Account, System, Service,
                         Transaction, Job, StorageCommitment)
 
+from .shortcuts import add_user_to_project, create_account
+
 
 class UserAdmin(admin.ModelAdmin):
     pass
@@ -10,7 +12,12 @@ admin.site.register(User, UserAdmin)
 
 
 class ProjectAdmin(admin.ModelAdmin):
-    pass
+    def save_model(self, request, obj, form, change):
+        super().save_model(request, obj, form, change)
+        if not change:
+            add_user_to_project(obj.pi, obj)
+            create_account(obj)
+
 admin.site.register(Project, ProjectAdmin)
 
 
